@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-07-27'; # DATE
-our $VERSION = '0.42'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.43'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -427,8 +427,15 @@ sub _process_script {
 
         last unless $cli->read_env;
         #$self->log_debug(["skipped file %s (script does not read env)", $filename]);
+
+        my $env_name = $cli->env_name;
+        if (!$env_name) {
+            $env_name = uc($prog);
+            $env_name =~ s/\W+/_/g;
+        }
+
         my @content;
-        push @content, "=head2 ", $cli->env_name, " => str\n\n";
+        push @content, "=head2 ", $env_name, " => str\n\n";
         push @content, "Specify additional command-line options\n\n";
 
         $self->add_text_to_section($document, join('', @content), 'ENVIRONMENT',
@@ -455,7 +462,9 @@ sub _process_script {
         # FILES section
         {
             my @content;
-            $config_filename = $cli->config_filename // $cli->program_name . ".conf";
+            $config_filename = $cli->config_filename //
+                ($cli->program_name ? $cli->program_name . ".conf" : undef) //
+                $prog . ".conf";
             $config_dirs = $cli->{config_dirs} // ['~/.config', '~', '/etc'];
 
             for my $config_dir (@{$config_dirs}) {
@@ -594,7 +603,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.42 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-07-27.
+This document describes version 0.43 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
